package com.ruoyi.system.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.TdExamnum;

/**
 * 考试结果Mapper接口
 * 
 * @author ruoyi
 * @date 2024-04-10
 */
public interface TdExamnumMapper extends BaseMapper<TdExamnum>
{
    /**
     * 查询考试结果
     * 
     * @param id 考试结果主键
     * @return 考试结果
     */
    public TdExamnum selectTdExamnumById(Long id);

    /**
     * 查询考试结果列表
     * 
     * @param tdExamnum 考试结果
     * @return 考试结果集合
     */
    public List<TdExamnum> selectTdExamnumList(TdExamnum tdExamnum);

    /**
     * 新增考试结果
     * 
     * @param tdExamnum 考试结果
     * @return 结果
     */
    public int insertTdExamnum(TdExamnum tdExamnum);

    /**
     * 修改考试结果
     * 
     * @param tdExamnum 考试结果
     * @return 结果
     */
    public int updateTdExamnum(TdExamnum tdExamnum);

    /**
     * 删除考试结果
     * 
     * @param id 考试结果主键
     * @return 结果
     */
    public int deleteTdExamnumById(Long id);

    /**
     * 批量删除考试结果
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTdExamnumByIds(String[] ids);
}
